@@ -10,23 +10,23 @@ fn test_model() {
     assert_eq!(
         sql,
         "CREATE TYPE \"Foo\" AS ENUM('Bar', 'Baz'); \
-         CREATE TABLE nameds (\
+         CREATE TABLE named (\
              id serial NOT NULL, \
              name text NOT NULL, \
              num bigint NOT NULL, \
              foo \"Foo\" NOT NULL, \
              wrap integer NOT NULL, \
-             CONSTRAINT nameds_pkey PRIMARY KEY (id)\
+             CONSTRAINT named_pkey PRIMARY KEY (id)\
          )"
     );
 
     assert_eq!(
         PostgreSql::table::<Dependent>().to_string(),
-        "CREATE TABLE dependents (\
-             id serial NOT NULL, \
+        "CREATE TABLE dependent (\
+             dep_id serial NOT NULL, \
              named integer NOT NULL, \
-             CONSTRAINT dependents_pkey PRIMARY KEY (id), \
-             CONSTRAINT named FOREIGN KEY (named) REFERENCES nameds (id)\
+             CONSTRAINT named FOREIGN KEY (named) REFERENCES named (id), \
+             CONSTRAINT dependent_pkey PRIMARY KEY (dep_id)\
          )"
     )
 }
@@ -56,6 +56,7 @@ struct Wrap(i32);
 #[allow(dead_code)]
 #[model]
 struct Dependent {
-    id: Serial<i32>,
+    #[model(primary_key)]
+    dep_id: Serial<i32>,
     named: <Named as ModelMeta>::PrimaryKey,
 }
